class TimeKeeper::CustomTime
  attr_accessor :time_in_str

  TIME_FORMAT_REGEX = /^((\d){1}|(\d){2})((:(\d){2}){1})?([ ])*(am|pm)?$/i

  include ActiveModel::Validations

  validates :time_in_str, :presence => true, :format => {:with => TimeKeeper::CustomTime::TIME_FORMAT_REGEX}

  def initialize(time_in_str)
    @time_in_str = time_in_str.downcase.strip
  end

  def parse
    @parsed_time = TimeKeeper::Parser::Base.build(@time_in_str).parse
    self
  end

  def in_seconds
    raise "Please parse the time before extracting in seconds" unless @parsed_time
    @parsed_time.hour * 3600 + @parsed_time.min * 60
  end

  def in_minutes
    raise "Please parse the time before extracting in minutes" unless @parsed_time
    @parsed_time.hour * 60 + @parsed_time.min
  end

  def in_hours
    raise "Please parse the time before extracting in hours" unless @parsed_time
    @parsed_time.hour + ((@parsed_time.min.to_f / 60) * 100).round.to_f/100
  end

  def to_s
    h = (self.in_minutes.to_i / 60)
    m = (self.in_minutes.to_i % 60)
    "%.2d:%.2d" % [h,m]
  end
end
