module TimeKeeper
  module Parser
    class Base
      attr_accessor :time_str, :hour, :min

      TIME_FORMAT_REGEX = /^((\d){1}|(\d){2})((:(\d){2}){1})?([ ])*(am|pm)?$/i

      include ActiveModel::Validations

      validates :time_str, :presence => true, :format => {:with => TimeKeeper::Parser::Base::TIME_FORMAT_REGEX}

      validate :time_is_valid

      def initialize(time_str)
        @time_str = time_str
        raise "#{time_str} is not a valid time" unless self.valid?
      end

      def self.build(time_in_str)
        if self.meridian_format?(time_in_str)
          TimeKeeper::Parser::Meridian.new(time_in_str)
        else
          TimeKeeper::Parser::Military.new(time_in_str)
        end
      end

      def parse
        raise NotImplementedError
      end

      def self.meridian_format?(time_in_str)
        time_in_str.downcase =~ /(am|pm)/
      end

      private

      def time_is_valid
        raise NotImplementedError
      end

      def extract_hour
        raise NotImplementedError
      end

      def extract_min(min_of_day)
        @min = min_of_day.blank? ? 0 : min_of_day[1..-1].strip.to_i
      end
    end
  end
end