module TimeKeeper
  module Parser
    class Meridian < Base
      TIME_FORMAT_REGEX = /^((\d){1}|(\d){2})((:(\d){2}){1})?([ ])*(am|pm)$/i

      validates :time_str, :presence => true, :format => {:with => TimeKeeper::Parser::Meridian::TIME_FORMAT_REGEX}

      def parse
        matched_data = @time_str.match(TimeKeeper::Parser::Meridian::TIME_FORMAT_REGEX)
        extract_hour(matched_data[1], matched_data[8])
        extract_min(matched_data[4])
        self
      end

      private

      def time_is_valid
        matched_data = @time_str.match(TimeKeeper::Parser::Meridian::TIME_FORMAT_REGEX)
        valid = ((1..12) === matched_data[1].to_i && (0...60) === matched_data[4].gsub(':', '').to_i)
        self.errors.add(:base, "Either hour or min is not valid") unless valid
        valid
      end

      def extract_hour(hour_of_day, meridian_status)
        hour_of_day = hour_of_day.strip.to_i
        @hour = 0
        if hour_of_day == 12 && meridian_status == "am"
          @hour = 0
        elsif hour_of_day == 12 && meridian_status == "pm"
          @hour = 12
        elsif hour_of_day > 0 && hour_of_day <= 12 && meridian_status == "am"
          @hour = hour_of_day
        elsif hour_of_day > 0 && hour_of_day <= 12 && meridian_status == "pm"
          @hour = hour_of_day + 12
        end
        @hour
      end
    end
  end
end