class TimeKeeper::TimeRange
  TIME_FORMAT_REGEX = /^([0-9]){1,2}(:[0-9]{2})?([ ])*(am|pm)?([ ])*(to|-)([ ])*([0-9]){1,2}(:[0-9]{2})?([ ])*(am|pm)?$/i

  attr_accessor :range, :start_time, :end_time, :start_day, :end_day

  include ActiveModel::Validations

  validates :range, :presence => true, :format => {:with => TimeKeeper::TimeRange::TIME_FORMAT_REGEX}

  def initialize(range)
    @range = range.strip.downcase.gsub(/\s*(-|to)\s*/, '-')
  end

  def parse
    raise "The range data (#{range.inspect}) you have provided is invalid" unless self.valid?
    parsed_range = @range.gsub('to', '-').split('-').map(&:strip)
    @start_time = TimeKeeper::CustomTime.new(parsed_range.first).parse
    @end_time = TimeKeeper::CustomTime.new(parsed_range.last).parse
    @start_day = 0
    @end_day = days_elapsed
    self
  end

  def days_elapsed
    @start_time.in_seconds > @end_time.in_seconds ? 1 : 0
  end

  def duration_in_seconds
    (days_elapsed * 24 * 60 * 60) + (@end_time.in_seconds - @start_time.in_seconds)
  end

  def duration_in_minutes
    ((duration_in_seconds.to_f/60)*100).round.to_f/100
  end

  def duration_in_hours
    ((duration_in_seconds.to_f/3600)*100).round.to_f/100
  end
end