class TimeKeeper::TimeRangeCollection
  TIME_FORMAT_REGEX = /^(\s*(to|-)\s*)+$/

  attr_accessor :time_ranges_str, :time_ranges

  include ActiveModel::Validations

  validates :time_ranges_str, :presence => true, :format => {:with => TimeKeeper::TimeRangeCollection::TIME_FORMAT_REGEX}

  def initialize(time_ranges_str)
    @time_ranges_str = time_ranges_str.strip.gsub(/\s*(-|to)\s*/, "-")
  end

  def parse
    spans = @time_ranges_str.split(/\s*\n\s*/).map(&:strip)
    previous_time_range = nil
    @time_ranges = spans.inject([]) do |result, span|
      time_range = TimeKeeper::TimeRange.new(span.strip).parse
      if previous_time_range
        time_range.start_day = (time_range.start_time.in_seconds < previous_time_range.end_time.in_seconds ? previous_time_range.end_day + 1 : previous_time_range.end_day)
        time_range.end_day = time_range.start_day + time_range.days_elapsed
      end
      result << time_range
      previous_time_range = time_range
      result
    end
    self
  end
end